#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011, 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

CURPATH=$(dirname $0)

. $CURPATH/initSC.sh

#If any of the configuration is incorrect, that means it is not a supported
#SC environment.  So, gracefully exit

if [ $? -ne 0 ] ; then
   exit 0
fi

LOGFILE=$DIRHOME/log/SCRestore.log

#It's for Defect 190012, specifying a new backup directory.
#And the parameter preprocess script is moved into the code StoreageControlExt.java.
TARGET_DIR=$1
BACKUP_DIR=$2

#Set Paths.
BACKUPFILE=/tmp/sc_migrate_options.backup
RESTOREFILE=/tmp/sc_migrate_options.restore
export BACKUP_DIR

#If the sc_advmgr.properties file does not exist, SC is not installed, and we don't need to do anything.
if [ ! -f $DIRHOME/proddata/advmgr/sc_advmgr.properties ] ; then
   echo "Storage Control not installed. We don't need to restore" >> $LOGFILE
   exit 0
else 
   echo "Not migration path" >> $LOGFILE
fi  

#Copy Storage Control files from the target back to the Director file structure.
function CopySCFiles
{
    if [ -f $TARGET_DIR/etpc.javaopt ] ; then
       cp -f $TARGET_DIR/etpc.javaopt $DIRHOME/lwi/conf/overrides
    fi
    if [ -f $TARGET_DIR/sc_advmgr.properties ] ; then
       cp -f $TARGET_DIR/sc_advmgr.properties $DIRHOME/proddata/advmgr
    fi
}

#Execute SCMigrateDB.java with specified parameters.
"$JAVAPATH/java" -DBACKUPDIR=$BACKUP_DIR -DBACKUPFILE=$BACKUPFILE -DRESTOREFILE=$RESTOREFILE -cp $CLASSPATH SCMigrateDB $DIRHOME $TPCHOME $*

if [ $? != 0 ] ; then
  displayMessage "MIGRATION_FAILED" >> $LOGFILE
  # Remove the backup and restore files if they exist
  rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
  exit -5
fi

#If the restore file exists, run SCMigDBSupport.sh
if [ -f $RESTOREFILE ] ; then
  $DIRHOME/StorageControl/bin/SCMigDBSupport.sh $RESTOREFILE $DIRHOME
  if [ $? != 0 ] ; then
     displayMessage "MIGRATION_RESTORE_FAILED" >> $LOGFILE
     # Remove the backup and restore files if they exist
     rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
     exit -8
  fi
  CopySCFiles
else
  displayMessage "MIGRATION_RESTORE_NOT_FOUND" >> $LOGFILE
  # Remove the backup and restore files if they exist
  rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
  exit -6
fi

if [ $? -eq 0 ] ; then
   displayMessage "SCRESTORE_SUCCESS" >> $LOGFILE
   # Remove the backup and restore files if they exist
   rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
else
   displayMessage "SCRESTORE_FAILED" >> $LOGFILE
   # Remove the backup and restore files if they exist
   rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
fi
